"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UrlFieldErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _UrlFieldError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UrlFieldError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = UrlFieldErrorEnum.UrlFieldError.V(0)
        UNKNOWN = UrlFieldErrorEnum.UrlFieldError.V(1)
        INVALID_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(2)
        INVALID_TAG_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(3)
        MISSING_TRACKING_URL_TEMPLATE_TAG = UrlFieldErrorEnum.UrlFieldError.V(4)
        MISSING_PROTOCOL_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(5)
        INVALID_PROTOCOL_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(6)
        MALFORMED_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(7)
        MISSING_HOST_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(8)
        INVALID_TLD_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(9)
        REDUNDANT_NESTED_TRACKING_URL_TEMPLATE_TAG = UrlFieldErrorEnum.UrlFieldError.V(
            10
        )
        INVALID_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(11)
        INVALID_TAG_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(12)
        REDUNDANT_NESTED_FINAL_URL_TAG = UrlFieldErrorEnum.UrlFieldError.V(13)
        MISSING_PROTOCOL_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(14)
        INVALID_PROTOCOL_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(15)
        MALFORMED_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(16)
        MISSING_HOST_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(17)
        INVALID_TLD_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(18)
        INVALID_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(19)
        INVALID_TAG_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(20)
        REDUNDANT_NESTED_FINAL_MOBILE_URL_TAG = UrlFieldErrorEnum.UrlFieldError.V(21)
        MISSING_PROTOCOL_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(22)
        INVALID_PROTOCOL_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(23)
        MALFORMED_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(24)
        MISSING_HOST_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(25)
        INVALID_TLD_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(26)
        INVALID_FINAL_APP_URL = UrlFieldErrorEnum.UrlFieldError.V(27)
        INVALID_TAG_IN_FINAL_APP_URL = UrlFieldErrorEnum.UrlFieldError.V(28)
        REDUNDANT_NESTED_FINAL_APP_URL_TAG = UrlFieldErrorEnum.UrlFieldError.V(29)
        MULTIPLE_APP_URLS_FOR_OSTYPE = UrlFieldErrorEnum.UrlFieldError.V(30)
        INVALID_OSTYPE = UrlFieldErrorEnum.UrlFieldError.V(31)
        INVALID_PROTOCOL_FOR_APP_URL = UrlFieldErrorEnum.UrlFieldError.V(32)
        INVALID_PACKAGE_ID_FOR_APP_URL = UrlFieldErrorEnum.UrlFieldError.V(33)
        URL_CUSTOM_PARAMETERS_COUNT_EXCEEDS_LIMIT = UrlFieldErrorEnum.UrlFieldError.V(
            34
        )
        INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_KEY = (
            UrlFieldErrorEnum.UrlFieldError.V(39)
        )
        INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_VALUE = (
            UrlFieldErrorEnum.UrlFieldError.V(40)
        )
        INVALID_TAG_IN_URL_CUSTOM_PARAMETER_VALUE = UrlFieldErrorEnum.UrlFieldError.V(
            41
        )
        REDUNDANT_NESTED_URL_CUSTOM_PARAMETER_TAG = UrlFieldErrorEnum.UrlFieldError.V(
            42
        )
        MISSING_PROTOCOL = UrlFieldErrorEnum.UrlFieldError.V(43)
        INVALID_PROTOCOL = UrlFieldErrorEnum.UrlFieldError.V(52)
        INVALID_URL = UrlFieldErrorEnum.UrlFieldError.V(44)
        DESTINATION_URL_DEPRECATED = UrlFieldErrorEnum.UrlFieldError.V(45)
        INVALID_TAG_IN_URL = UrlFieldErrorEnum.UrlFieldError.V(46)
        MISSING_URL_TAG = UrlFieldErrorEnum.UrlFieldError.V(47)
        DUPLICATE_URL_ID = UrlFieldErrorEnum.UrlFieldError.V(48)
        INVALID_URL_ID = UrlFieldErrorEnum.UrlFieldError.V(49)
        FINAL_URL_SUFFIX_MALFORMED = UrlFieldErrorEnum.UrlFieldError.V(50)
        INVALID_TAG_IN_FINAL_URL_SUFFIX = UrlFieldErrorEnum.UrlFieldError.V(51)
        INVALID_TOP_LEVEL_DOMAIN = UrlFieldErrorEnum.UrlFieldError.V(53)
        MALFORMED_TOP_LEVEL_DOMAIN = UrlFieldErrorEnum.UrlFieldError.V(54)
        MALFORMED_URL = UrlFieldErrorEnum.UrlFieldError.V(55)
        MISSING_HOST = UrlFieldErrorEnum.UrlFieldError.V(56)
        NULL_CUSTOM_PARAMETER_VALUE = UrlFieldErrorEnum.UrlFieldError.V(57)
    class UrlFieldError(metaclass=_UrlFieldError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = UrlFieldErrorEnum.UrlFieldError.V(0)
    UNKNOWN = UrlFieldErrorEnum.UrlFieldError.V(1)
    INVALID_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(2)
    INVALID_TAG_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(3)
    MISSING_TRACKING_URL_TEMPLATE_TAG = UrlFieldErrorEnum.UrlFieldError.V(4)
    MISSING_PROTOCOL_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(5)
    INVALID_PROTOCOL_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(6)
    MALFORMED_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(7)
    MISSING_HOST_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(8)
    INVALID_TLD_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(9)
    REDUNDANT_NESTED_TRACKING_URL_TEMPLATE_TAG = UrlFieldErrorEnum.UrlFieldError.V(10)
    INVALID_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(11)
    INVALID_TAG_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(12)
    REDUNDANT_NESTED_FINAL_URL_TAG = UrlFieldErrorEnum.UrlFieldError.V(13)
    MISSING_PROTOCOL_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(14)
    INVALID_PROTOCOL_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(15)
    MALFORMED_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(16)
    MISSING_HOST_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(17)
    INVALID_TLD_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(18)
    INVALID_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(19)
    INVALID_TAG_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(20)
    REDUNDANT_NESTED_FINAL_MOBILE_URL_TAG = UrlFieldErrorEnum.UrlFieldError.V(21)
    MISSING_PROTOCOL_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(22)
    INVALID_PROTOCOL_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(23)
    MALFORMED_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(24)
    MISSING_HOST_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(25)
    INVALID_TLD_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(26)
    INVALID_FINAL_APP_URL = UrlFieldErrorEnum.UrlFieldError.V(27)
    INVALID_TAG_IN_FINAL_APP_URL = UrlFieldErrorEnum.UrlFieldError.V(28)
    REDUNDANT_NESTED_FINAL_APP_URL_TAG = UrlFieldErrorEnum.UrlFieldError.V(29)
    MULTIPLE_APP_URLS_FOR_OSTYPE = UrlFieldErrorEnum.UrlFieldError.V(30)
    INVALID_OSTYPE = UrlFieldErrorEnum.UrlFieldError.V(31)
    INVALID_PROTOCOL_FOR_APP_URL = UrlFieldErrorEnum.UrlFieldError.V(32)
    INVALID_PACKAGE_ID_FOR_APP_URL = UrlFieldErrorEnum.UrlFieldError.V(33)
    URL_CUSTOM_PARAMETERS_COUNT_EXCEEDS_LIMIT = UrlFieldErrorEnum.UrlFieldError.V(34)
    INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_KEY = UrlFieldErrorEnum.UrlFieldError.V(
        39
    )
    INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_VALUE = (
        UrlFieldErrorEnum.UrlFieldError.V(40)
    )
    INVALID_TAG_IN_URL_CUSTOM_PARAMETER_VALUE = UrlFieldErrorEnum.UrlFieldError.V(41)
    REDUNDANT_NESTED_URL_CUSTOM_PARAMETER_TAG = UrlFieldErrorEnum.UrlFieldError.V(42)
    MISSING_PROTOCOL = UrlFieldErrorEnum.UrlFieldError.V(43)
    INVALID_PROTOCOL = UrlFieldErrorEnum.UrlFieldError.V(52)
    INVALID_URL = UrlFieldErrorEnum.UrlFieldError.V(44)
    DESTINATION_URL_DEPRECATED = UrlFieldErrorEnum.UrlFieldError.V(45)
    INVALID_TAG_IN_URL = UrlFieldErrorEnum.UrlFieldError.V(46)
    MISSING_URL_TAG = UrlFieldErrorEnum.UrlFieldError.V(47)
    DUPLICATE_URL_ID = UrlFieldErrorEnum.UrlFieldError.V(48)
    INVALID_URL_ID = UrlFieldErrorEnum.UrlFieldError.V(49)
    FINAL_URL_SUFFIX_MALFORMED = UrlFieldErrorEnum.UrlFieldError.V(50)
    INVALID_TAG_IN_FINAL_URL_SUFFIX = UrlFieldErrorEnum.UrlFieldError.V(51)
    INVALID_TOP_LEVEL_DOMAIN = UrlFieldErrorEnum.UrlFieldError.V(53)
    MALFORMED_TOP_LEVEL_DOMAIN = UrlFieldErrorEnum.UrlFieldError.V(54)
    MALFORMED_URL = UrlFieldErrorEnum.UrlFieldError.V(55)
    MISSING_HOST = UrlFieldErrorEnum.UrlFieldError.V(56)
    NULL_CUSTOM_PARAMETER_VALUE = UrlFieldErrorEnum.UrlFieldError.V(57)
    def __init__(
        self,
    ) -> None: ...

global___UrlFieldErrorEnum = UrlFieldErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.media_type_pb2
import google.ads.google_ads.v5.proto.enums.mime_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MediaFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    MIME_TYPE_FIELD_NUMBER: builtins.int
    SOURCE_URL_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FILE_SIZE_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    MEDIA_BUNDLE_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    VIDEO_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    type: google.ads.google_ads.v5.proto.enums.media_type_pb2.MediaTypeEnum.MediaType.V = (
        ...
    )
    mime_type: google.ads.google_ads.v5.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = (
        ...
    )
    source_url: typing.Text = ...
    name: typing.Text = ...
    file_size: builtins.int = ...
    @property
    def image(self) -> global___MediaImage: ...
    @property
    def media_bundle(self) -> global___MediaBundle: ...
    @property
    def audio(self) -> global___MediaAudio: ...
    @property
    def video(self) -> global___MediaVideo: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        type: google.ads.google_ads.v5.proto.enums.media_type_pb2.MediaTypeEnum.MediaType.V = ...,
        mime_type: google.ads.google_ads.v5.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = ...,
        source_url: typing.Text = ...,
        name: typing.Text = ...,
        file_size: builtins.int = ...,
        image: typing.Optional[global___MediaImage] = ...,
        media_bundle: typing.Optional[global___MediaBundle] = ...,
        audio: typing.Optional[global___MediaAudio] = ...,
        video: typing.Optional[global___MediaVideo] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_file_size",
            b"_file_size",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_source_url",
            b"_source_url",
            "audio",
            b"audio",
            "file_size",
            b"file_size",
            "id",
            b"id",
            "image",
            b"image",
            "media_bundle",
            b"media_bundle",
            "mediatype",
            b"mediatype",
            "name",
            b"name",
            "source_url",
            b"source_url",
            "video",
            b"video",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_file_size",
            b"_file_size",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_source_url",
            b"_source_url",
            "audio",
            b"audio",
            "file_size",
            b"file_size",
            "id",
            b"id",
            "image",
            b"image",
            "media_bundle",
            b"media_bundle",
            "mediatype",
            b"mediatype",
            "mime_type",
            b"mime_type",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "source_url",
            b"source_url",
            "type",
            b"type",
            "video",
            b"video",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_file_size", b"_file_size"]
    ) -> typing_extensions.Literal["file_size"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_source_url", b"_source_url"]
    ) -> typing_extensions.Literal["source_url"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["mediatype", b"mediatype"]
    ) -> typing_extensions.Literal["image", "media_bundle", "audio", "video"]: ...

global___MediaFile = MediaFile

class MediaImage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    FULL_SIZE_IMAGE_URL_FIELD_NUMBER: builtins.int
    PREVIEW_SIZE_IMAGE_URL_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    full_size_image_url: typing.Text = ...
    preview_size_image_url: typing.Text = ...
    def __init__(
        self,
        *,
        data: builtins.bytes = ...,
        full_size_image_url: typing.Text = ...,
        preview_size_image_url: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_data",
            b"_data",
            "_full_size_image_url",
            b"_full_size_image_url",
            "_preview_size_image_url",
            b"_preview_size_image_url",
            "data",
            b"data",
            "full_size_image_url",
            b"full_size_image_url",
            "preview_size_image_url",
            b"preview_size_image_url",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_data",
            b"_data",
            "_full_size_image_url",
            b"_full_size_image_url",
            "_preview_size_image_url",
            b"_preview_size_image_url",
            "data",
            b"data",
            "full_size_image_url",
            b"full_size_image_url",
            "preview_size_image_url",
            b"preview_size_image_url",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_data", b"_data"]
    ) -> typing_extensions.Literal["data"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_full_size_image_url", b"_full_size_image_url"
        ],
    ) -> typing_extensions.Literal["full_size_image_url"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_preview_size_image_url", b"_preview_size_image_url"
        ],
    ) -> typing_extensions.Literal["preview_size_image_url"]: ...

global___MediaImage = MediaImage

class MediaBundle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    url: typing.Text = ...
    def __init__(
        self,
        *,
        data: builtins.bytes = ...,
        url: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_data", b"_data", "_url", b"_url", "data", b"data", "url", b"url"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_data", b"_data", "_url", b"_url", "data", b"data", "url", b"url"
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_data", b"_data"]
    ) -> typing_extensions.Literal["data"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_url", b"_url"]
    ) -> typing_extensions.Literal["url"]: ...

global___MediaBundle = MediaBundle

class MediaAudio(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AD_DURATION_MILLIS_FIELD_NUMBER: builtins.int
    ad_duration_millis: builtins.int = ...
    def __init__(
        self,
        *,
        ad_duration_millis: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_duration_millis",
            b"_ad_duration_millis",
            "ad_duration_millis",
            b"ad_duration_millis",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_duration_millis",
            b"_ad_duration_millis",
            "ad_duration_millis",
            b"ad_duration_millis",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_ad_duration_millis", b"_ad_duration_millis"
        ],
    ) -> typing_extensions.Literal["ad_duration_millis"]: ...

global___MediaAudio = MediaAudio

class MediaVideo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AD_DURATION_MILLIS_FIELD_NUMBER: builtins.int
    YOUTUBE_VIDEO_ID_FIELD_NUMBER: builtins.int
    ADVERTISING_ID_CODE_FIELD_NUMBER: builtins.int
    ISCI_CODE_FIELD_NUMBER: builtins.int
    ad_duration_millis: builtins.int = ...
    youtube_video_id: typing.Text = ...
    advertising_id_code: typing.Text = ...
    isci_code: typing.Text = ...
    def __init__(
        self,
        *,
        ad_duration_millis: builtins.int = ...,
        youtube_video_id: typing.Text = ...,
        advertising_id_code: typing.Text = ...,
        isci_code: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_duration_millis",
            b"_ad_duration_millis",
            "_advertising_id_code",
            b"_advertising_id_code",
            "_isci_code",
            b"_isci_code",
            "_youtube_video_id",
            b"_youtube_video_id",
            "ad_duration_millis",
            b"ad_duration_millis",
            "advertising_id_code",
            b"advertising_id_code",
            "isci_code",
            b"isci_code",
            "youtube_video_id",
            b"youtube_video_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_duration_millis",
            b"_ad_duration_millis",
            "_advertising_id_code",
            b"_advertising_id_code",
            "_isci_code",
            b"_isci_code",
            "_youtube_video_id",
            b"_youtube_video_id",
            "ad_duration_millis",
            b"ad_duration_millis",
            "advertising_id_code",
            b"advertising_id_code",
            "isci_code",
            b"isci_code",
            "youtube_video_id",
            b"youtube_video_id",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_ad_duration_millis", b"_ad_duration_millis"
        ],
    ) -> typing_extensions.Literal["ad_duration_millis"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_advertising_id_code", b"_advertising_id_code"
        ],
    ) -> typing_extensions.Literal["advertising_id_code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_isci_code", b"_isci_code"]
    ) -> typing_extensions.Literal["isci_code"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_youtube_video_id", b"_youtube_video_id"
        ],
    ) -> typing_extensions.Literal["youtube_video_id"]: ...

global___MediaVideo = MediaVideo



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.paid_organic_search_term_view_pb2
import grpc

from .paid_organic_search_term_view_service_pb2 import *

class PaidOrganicSearchTermViewServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetPaidOrganicSearchTermView(
        self,
        request: global___GetPaidOrganicSearchTermViewRequest,
    ) -> google.ads.google_ads.v5.proto.resources.paid_organic_search_term_view_pb2.PaidOrganicSearchTermView: ...

class PaidOrganicSearchTermViewServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetPaidOrganicSearchTermView(
        self,
        request: global___GetPaidOrganicSearchTermViewRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.paid_organic_search_term_view_pb2.PaidOrganicSearchTermView: ...

def add_PaidOrganicSearchTermViewServiceServicer_to_server(
    servicer: PaidOrganicSearchTermViewServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.geographic_view_pb2
import grpc

from .geographic_view_service_pb2 import *

class GeographicViewServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetGeographicView(
        self,
        request: global___GetGeographicViewRequest,
    ) -> google.ads.google_ads.v4.proto.resources.geographic_view_pb2.GeographicView: ...

class GeographicViewServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetGeographicView(
        self,
        request: global___GetGeographicViewRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.geographic_view_pb2.GeographicView: ...

def add_GeographicViewServiceServicer_to_server(
    servicer: GeographicViewServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.remarketing_action_pb2
import grpc

from .remarketing_action_service_pb2 import *

class RemarketingActionServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetRemarketingAction(
        self,
        request: global___GetRemarketingActionRequest,
    ) -> google.ads.google_ads.v6.proto.resources.remarketing_action_pb2.RemarketingAction: ...
    def MutateRemarketingActions(
        self,
        request: global___MutateRemarketingActionsRequest,
    ) -> global___MutateRemarketingActionsResponse: ...

class RemarketingActionServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetRemarketingAction(
        self,
        request: global___GetRemarketingActionRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.remarketing_action_pb2.RemarketingAction: ...
    @abc.abstractmethod
    def MutateRemarketingActions(
        self,
        request: global___MutateRemarketingActionsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateRemarketingActionsResponse: ...

def add_RemarketingActionServiceServicer_to_server(
    servicer: RemarketingActionServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.access_role_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerUserAccess(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    EMAIL_ADDRESS_FIELD_NUMBER: builtins.int
    ACCESS_ROLE_FIELD_NUMBER: builtins.int
    ACCESS_CREATION_DATE_TIME_FIELD_NUMBER: builtins.int
    INVITER_USER_EMAIL_ADDRESS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    user_id: builtins.int = ...
    email_address: typing.Text = ...
    access_role: google.ads.google_ads.v6.proto.enums.access_role_pb2.AccessRoleEnum.AccessRole.V = (
        ...
    )
    access_creation_date_time: typing.Text = ...
    inviter_user_email_address: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        user_id: builtins.int = ...,
        email_address: typing.Text = ...,
        access_role: google.ads.google_ads.v6.proto.enums.access_role_pb2.AccessRoleEnum.AccessRole.V = ...,
        access_creation_date_time: typing.Text = ...,
        inviter_user_email_address: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_access_creation_date_time",
            b"_access_creation_date_time",
            "_email_address",
            b"_email_address",
            "_inviter_user_email_address",
            b"_inviter_user_email_address",
            "access_creation_date_time",
            b"access_creation_date_time",
            "email_address",
            b"email_address",
            "inviter_user_email_address",
            b"inviter_user_email_address",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_access_creation_date_time",
            b"_access_creation_date_time",
            "_email_address",
            b"_email_address",
            "_inviter_user_email_address",
            b"_inviter_user_email_address",
            "access_creation_date_time",
            b"access_creation_date_time",
            "access_role",
            b"access_role",
            "email_address",
            b"email_address",
            "inviter_user_email_address",
            b"inviter_user_email_address",
            "resource_name",
            b"resource_name",
            "user_id",
            b"user_id",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_access_creation_date_time", b"_access_creation_date_time"
        ],
    ) -> typing_extensions.Literal["access_creation_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_email_address", b"_email_address"],
    ) -> typing_extensions.Literal["email_address"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_inviter_user_email_address", b"_inviter_user_email_address"
        ],
    ) -> typing_extensions.Literal["inviter_user_email_address"]: ...

global___CustomerUserAccess = CustomerUserAccess



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TrackingCodeTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _TrackingCodeType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TrackingCodeType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = TrackingCodeTypeEnum.TrackingCodeType.V(0)
        UNKNOWN = TrackingCodeTypeEnum.TrackingCodeType.V(1)
        WEBPAGE = TrackingCodeTypeEnum.TrackingCodeType.V(2)
        WEBPAGE_ONCLICK = TrackingCodeTypeEnum.TrackingCodeType.V(3)
        CLICK_TO_CALL = TrackingCodeTypeEnum.TrackingCodeType.V(4)
        WEBSITE_CALL = TrackingCodeTypeEnum.TrackingCodeType.V(5)
    class TrackingCodeType(metaclass=_TrackingCodeType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = TrackingCodeTypeEnum.TrackingCodeType.V(0)
    UNKNOWN = TrackingCodeTypeEnum.TrackingCodeType.V(1)
    WEBPAGE = TrackingCodeTypeEnum.TrackingCodeType.V(2)
    WEBPAGE_ONCLICK = TrackingCodeTypeEnum.TrackingCodeType.V(3)
    CLICK_TO_CALL = TrackingCodeTypeEnum.TrackingCodeType.V(4)
    WEBSITE_CALL = TrackingCodeTypeEnum.TrackingCodeType.V(5)
    def __init__(
        self,
    ) -> None: ...

global___TrackingCodeTypeEnum = TrackingCodeTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.common.dates_pb2
import google.ads.google_ads.v5.proto.enums.invoice_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Invoice(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class AccountBudgetSummary(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CUSTOMER_FIELD_NUMBER: builtins.int
        CUSTOMER_DESCRIPTIVE_NAME_FIELD_NUMBER: builtins.int
        ACCOUNT_BUDGET_FIELD_NUMBER: builtins.int
        ACCOUNT_BUDGET_NAME_FIELD_NUMBER: builtins.int
        PURCHASE_ORDER_NUMBER_FIELD_NUMBER: builtins.int
        SUBTOTAL_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
        TAX_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
        TOTAL_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
        BILLABLE_ACTIVITY_DATE_RANGE_FIELD_NUMBER: builtins.int
        @property
        def customer(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def customer_descriptive_name(
            self,
        ) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def account_budget(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def account_budget_name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def purchase_order_number(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def subtotal_amount_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
        @property
        def tax_amount_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
        @property
        def total_amount_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
        @property
        def billable_activity_date_range(
            self,
        ) -> google.ads.google_ads.v5.proto.common.dates_pb2.DateRange: ...
        def __init__(
            self,
            *,
            customer: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
            customer_descriptive_name: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            account_budget: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            account_budget_name: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            purchase_order_number: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            subtotal_amount_micros: typing.Optional[
                google.protobuf.wrappers_pb2.Int64Value
            ] = ...,
            tax_amount_micros: typing.Optional[
                google.protobuf.wrappers_pb2.Int64Value
            ] = ...,
            total_amount_micros: typing.Optional[
                google.protobuf.wrappers_pb2.Int64Value
            ] = ...,
            billable_activity_date_range: typing.Optional[
                google.ads.google_ads.v5.proto.common.dates_pb2.DateRange
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "account_budget",
                b"account_budget",
                "account_budget_name",
                b"account_budget_name",
                "billable_activity_date_range",
                b"billable_activity_date_range",
                "customer",
                b"customer",
                "customer_descriptive_name",
                b"customer_descriptive_name",
                "purchase_order_number",
                b"purchase_order_number",
                "subtotal_amount_micros",
                b"subtotal_amount_micros",
                "tax_amount_micros",
                b"tax_amount_micros",
                "total_amount_micros",
                b"total_amount_micros",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "account_budget",
                b"account_budget",
                "account_budget_name",
                b"account_budget_name",
                "billable_activity_date_range",
                b"billable_activity_date_range",
                "customer",
                b"customer",
                "customer_descriptive_name",
                b"customer_descriptive_name",
                "purchase_order_number",
                b"purchase_order_number",
                "subtotal_amount_micros",
                b"subtotal_amount_micros",
                "tax_amount_micros",
                b"tax_amount_micros",
                "total_amount_micros",
                b"total_amount_micros",
            ],
        ) -> None: ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    BILLING_SETUP_FIELD_NUMBER: builtins.int
    PAYMENTS_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    PAYMENTS_PROFILE_ID_FIELD_NUMBER: builtins.int
    ISSUE_DATE_FIELD_NUMBER: builtins.int
    DUE_DATE_FIELD_NUMBER: builtins.int
    SERVICE_DATE_RANGE_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    INVOICE_LEVEL_ADJUSTMENTS_MICROS_FIELD_NUMBER: builtins.int
    SUBTOTAL_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    TAX_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    TOTAL_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    CORRECTED_INVOICE_FIELD_NUMBER: builtins.int
    REPLACED_INVOICES_FIELD_NUMBER: builtins.int
    PDF_URL_FIELD_NUMBER: builtins.int
    ACCOUNT_BUDGET_SUMMARIES_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    type: google.ads.google_ads.v5.proto.enums.invoice_type_pb2.InvoiceTypeEnum.InvoiceType.V = (
        ...
    )
    @property
    def id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def billing_setup(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def payments_account_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def payments_profile_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def issue_date(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def due_date(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def service_date_range(
        self,
    ) -> google.ads.google_ads.v5.proto.common.dates_pb2.DateRange: ...
    @property
    def currency_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def invoice_level_adjustments_micros(
        self,
    ) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def subtotal_amount_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def tax_amount_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def total_amount_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def corrected_invoice(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def replaced_invoices(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def pdf_url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def account_budget_summaries(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___Invoice.AccountBudgetSummary
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        type: google.ads.google_ads.v5.proto.enums.invoice_type_pb2.InvoiceTypeEnum.InvoiceType.V = ...,
        billing_setup: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        payments_account_id: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        payments_profile_id: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        issue_date: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        due_date: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        service_date_range: typing.Optional[
            google.ads.google_ads.v5.proto.common.dates_pb2.DateRange
        ] = ...,
        currency_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        invoice_level_adjustments_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        subtotal_amount_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        tax_amount_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        total_amount_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        corrected_invoice: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        replaced_invoices: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        pdf_url: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        account_budget_summaries: typing.Optional[
            typing.Iterable[global___Invoice.AccountBudgetSummary]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "billing_setup",
            b"billing_setup",
            "corrected_invoice",
            b"corrected_invoice",
            "currency_code",
            b"currency_code",
            "due_date",
            b"due_date",
            "id",
            b"id",
            "invoice_level_adjustments_micros",
            b"invoice_level_adjustments_micros",
            "issue_date",
            b"issue_date",
            "payments_account_id",
            b"payments_account_id",
            "payments_profile_id",
            b"payments_profile_id",
            "pdf_url",
            b"pdf_url",
            "service_date_range",
            b"service_date_range",
            "subtotal_amount_micros",
            b"subtotal_amount_micros",
            "tax_amount_micros",
            b"tax_amount_micros",
            "total_amount_micros",
            b"total_amount_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "account_budget_summaries",
            b"account_budget_summaries",
            "billing_setup",
            b"billing_setup",
            "corrected_invoice",
            b"corrected_invoice",
            "currency_code",
            b"currency_code",
            "due_date",
            b"due_date",
            "id",
            b"id",
            "invoice_level_adjustments_micros",
            b"invoice_level_adjustments_micros",
            "issue_date",
            b"issue_date",
            "payments_account_id",
            b"payments_account_id",
            "payments_profile_id",
            b"payments_profile_id",
            "pdf_url",
            b"pdf_url",
            "replaced_invoices",
            b"replaced_invoices",
            "resource_name",
            b"resource_name",
            "service_date_range",
            b"service_date_range",
            "subtotal_amount_micros",
            b"subtotal_amount_micros",
            "tax_amount_micros",
            b"tax_amount_micros",
            "total_amount_micros",
            b"total_amount_micros",
            "type",
            b"type",
        ],
    ) -> None: ...

global___Invoice = Invoice



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerUserAccessErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomerUserAccessError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomerUserAccessError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(0)
        UNKNOWN = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(1)
        INVALID_USER_ID = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(2)
        REMOVAL_DISALLOWED = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(3)
        DISALLOWED_ACCESS_ROLE = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(
            4
        )
        LAST_ADMIN_USER_OF_SERVING_CUSTOMER = (
            CustomerUserAccessErrorEnum.CustomerUserAccessError.V(5)
        )
        LAST_ADMIN_USER_OF_MANAGER = (
            CustomerUserAccessErrorEnum.CustomerUserAccessError.V(6)
        )
    class CustomerUserAccessError(metaclass=_CustomerUserAccessError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(0)
    UNKNOWN = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(1)
    INVALID_USER_ID = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(2)
    REMOVAL_DISALLOWED = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(3)
    DISALLOWED_ACCESS_ROLE = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(4)
    LAST_ADMIN_USER_OF_SERVING_CUSTOMER = (
        CustomerUserAccessErrorEnum.CustomerUserAccessError.V(5)
    )
    LAST_ADMIN_USER_OF_MANAGER = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(
        6
    )
    def __init__(
        self,
    ) -> None: ...

global___CustomerUserAccessErrorEnum = CustomerUserAccessErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.common.offline_user_data_pb2
import google.ads.google_ads.v5.proto.enums.offline_user_data_job_failure_reason_pb2
import google.ads.google_ads.v5.proto.enums.offline_user_data_job_status_pb2
import google.ads.google_ads.v5.proto.enums.offline_user_data_job_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class OfflineUserDataJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    FAILURE_REASON_FIELD_NUMBER: builtins.int
    CUSTOMER_MATCH_USER_LIST_METADATA_FIELD_NUMBER: builtins.int
    STORE_SALES_METADATA_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    type: google.ads.google_ads.v5.proto.enums.offline_user_data_job_type_pb2.OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V = (
        ...
    )
    status: google.ads.google_ads.v5.proto.enums.offline_user_data_job_status_pb2.OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V = (
        ...
    )
    failure_reason: google.ads.google_ads.v5.proto.enums.offline_user_data_job_failure_reason_pb2.OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V = (
        ...
    )
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def external_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def customer_match_user_list_metadata(
        self,
    ) -> google.ads.google_ads.v5.proto.common.offline_user_data_pb2.CustomerMatchUserListMetadata: ...
    @property
    def store_sales_metadata(
        self,
    ) -> google.ads.google_ads.v5.proto.common.offline_user_data_pb2.StoreSalesMetadata: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        external_id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        type: google.ads.google_ads.v5.proto.enums.offline_user_data_job_type_pb2.OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V = ...,
        status: google.ads.google_ads.v5.proto.enums.offline_user_data_job_status_pb2.OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V = ...,
        failure_reason: google.ads.google_ads.v5.proto.enums.offline_user_data_job_failure_reason_pb2.OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V = ...,
        customer_match_user_list_metadata: typing.Optional[
            google.ads.google_ads.v5.proto.common.offline_user_data_pb2.CustomerMatchUserListMetadata
        ] = ...,
        store_sales_metadata: typing.Optional[
            google.ads.google_ads.v5.proto.common.offline_user_data_pb2.StoreSalesMetadata
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "customer_match_user_list_metadata",
            b"customer_match_user_list_metadata",
            "external_id",
            b"external_id",
            "id",
            b"id",
            "metadata",
            b"metadata",
            "store_sales_metadata",
            b"store_sales_metadata",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_match_user_list_metadata",
            b"customer_match_user_list_metadata",
            "external_id",
            b"external_id",
            "failure_reason",
            b"failure_reason",
            "id",
            b"id",
            "metadata",
            b"metadata",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "store_sales_metadata",
            b"store_sales_metadata",
            "type",
            b"type",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["metadata", b"metadata"]
    ) -> typing_extensions.Literal[
        "customer_match_user_list_metadata", "store_sales_metadata"
    ]: ...

global___OfflineUserDataJob = OfflineUserDataJob



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PaymentsAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    PAYMENTS_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    PAYMENTS_PROFILE_ID_FIELD_NUMBER: builtins.int
    SECONDARY_PAYMENTS_PROFILE_ID_FIELD_NUMBER: builtins.int
    PAYING_MANAGER_CUSTOMER_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    payments_account_id: typing.Text = ...
    name: typing.Text = ...
    currency_code: typing.Text = ...
    payments_profile_id: typing.Text = ...
    secondary_payments_profile_id: typing.Text = ...
    paying_manager_customer: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        payments_account_id: typing.Text = ...,
        name: typing.Text = ...,
        currency_code: typing.Text = ...,
        payments_profile_id: typing.Text = ...,
        secondary_payments_profile_id: typing.Text = ...,
        paying_manager_customer: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_currency_code",
            b"_currency_code",
            "_name",
            b"_name",
            "_paying_manager_customer",
            b"_paying_manager_customer",
            "_payments_account_id",
            b"_payments_account_id",
            "_payments_profile_id",
            b"_payments_profile_id",
            "_secondary_payments_profile_id",
            b"_secondary_payments_profile_id",
            "currency_code",
            b"currency_code",
            "name",
            b"name",
            "paying_manager_customer",
            b"paying_manager_customer",
            "payments_account_id",
            b"payments_account_id",
            "payments_profile_id",
            b"payments_profile_id",
            "secondary_payments_profile_id",
            b"secondary_payments_profile_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_currency_code",
            b"_currency_code",
            "_name",
            b"_name",
            "_paying_manager_customer",
            b"_paying_manager_customer",
            "_payments_account_id",
            b"_payments_account_id",
            "_payments_profile_id",
            b"_payments_profile_id",
            "_secondary_payments_profile_id",
            b"_secondary_payments_profile_id",
            "currency_code",
            b"currency_code",
            "name",
            b"name",
            "paying_manager_customer",
            b"paying_manager_customer",
            "payments_account_id",
            b"payments_account_id",
            "payments_profile_id",
            b"payments_profile_id",
            "resource_name",
            b"resource_name",
            "secondary_payments_profile_id",
            b"secondary_payments_profile_id",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions.Literal["currency_code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_paying_manager_customer", b"_paying_manager_customer"
        ],
    ) -> typing_extensions.Literal["paying_manager_customer"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_payments_account_id", b"_payments_account_id"
        ],
    ) -> typing_extensions.Literal["payments_account_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_payments_profile_id", b"_payments_profile_id"
        ],
    ) -> typing_extensions.Literal["payments_profile_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_secondary_payments_profile_id", b"_secondary_payments_profile_id"
        ],
    ) -> typing_extensions.Literal["secondary_payments_profile_id"]: ...

global___PaymentsAccount = PaymentsAccount



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PlacementTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PlacementType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PlacementType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PlacementTypeEnum.PlacementType.V(0)
        UNKNOWN = PlacementTypeEnum.PlacementType.V(1)
        WEBSITE = PlacementTypeEnum.PlacementType.V(2)
        MOBILE_APP_CATEGORY = PlacementTypeEnum.PlacementType.V(3)
        MOBILE_APPLICATION = PlacementTypeEnum.PlacementType.V(4)
        YOUTUBE_VIDEO = PlacementTypeEnum.PlacementType.V(5)
        YOUTUBE_CHANNEL = PlacementTypeEnum.PlacementType.V(6)
    class PlacementType(metaclass=_PlacementType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PlacementTypeEnum.PlacementType.V(0)
    UNKNOWN = PlacementTypeEnum.PlacementType.V(1)
    WEBSITE = PlacementTypeEnum.PlacementType.V(2)
    MOBILE_APP_CATEGORY = PlacementTypeEnum.PlacementType.V(3)
    MOBILE_APPLICATION = PlacementTypeEnum.PlacementType.V(4)
    YOUTUBE_VIDEO = PlacementTypeEnum.PlacementType.V(5)
    YOUTUBE_CHANNEL = PlacementTypeEnum.PlacementType.V(6)
    def __init__(
        self,
    ) -> None: ...

global___PlacementTypeEnum = PlacementTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ConversionAdjustmentUploadErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ConversionAdjustmentUploadError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ConversionAdjustmentUploadError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(0)
        )
        UNKNOWN = ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(
            1
        )
        TOO_RECENT_CONVERSION_ACTION = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(2)
        )
        INVALID_CONVERSION_ACTION = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(3)
        )
        CONVERSION_ALREADY_RETRACTED = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(4)
        )
        CONVERSION_NOT_FOUND = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(5)
        )
        CONVERSION_EXPIRED = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(6)
        )
        ADJUSTMENT_PRECEDES_CONVERSION = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(7)
        )
        MORE_RECENT_RESTATEMENT_FOUND = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(8)
        )
        TOO_RECENT_CONVERSION = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(9)
        )
        CANNOT_RESTATE_CONVERSION_ACTION_THAT_ALWAYS_USES_DEFAULT_CONVERSION_VALUE = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(10)
        )
        TOO_MANY_ADJUSTMENTS_IN_REQUEST = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(11)
        )
        TOO_MANY_ADJUSTMENTS = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(12)
        )
    class ConversionAdjustmentUploadError(metaclass=_ConversionAdjustmentUploadError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(
        0
    )
    UNKNOWN = ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(1)
    TOO_RECENT_CONVERSION_ACTION = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(2)
    )
    INVALID_CONVERSION_ACTION = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(3)
    )
    CONVERSION_ALREADY_RETRACTED = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(4)
    )
    CONVERSION_NOT_FOUND = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(5)
    )
    CONVERSION_EXPIRED = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(6)
    )
    ADJUSTMENT_PRECEDES_CONVERSION = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(7)
    )
    MORE_RECENT_RESTATEMENT_FOUND = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(8)
    )
    TOO_RECENT_CONVERSION = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(9)
    )
    CANNOT_RESTATE_CONVERSION_ACTION_THAT_ALWAYS_USES_DEFAULT_CONVERSION_VALUE = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(10)
    )
    TOO_MANY_ADJUSTMENTS_IN_REQUEST = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(11)
    )
    TOO_MANY_ADJUSTMENTS = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(12)
    )
    def __init__(
        self,
    ) -> None: ...

global___ConversionAdjustmentUploadErrorEnum = ConversionAdjustmentUploadErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UserInterestTaxonomyTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _UserInterestTaxonomyType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            UserInterestTaxonomyType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(0)
        UNKNOWN = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(1)
        AFFINITY = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(2)
        IN_MARKET = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(3)
        MOBILE_APP_INSTALL_USER = (
            UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(4)
        )
        VERTICAL_GEO = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(5)
        NEW_SMART_PHONE_USER = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(
            6
        )
    class UserInterestTaxonomyType(metaclass=_UserInterestTaxonomyType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(0)
    UNKNOWN = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(1)
    AFFINITY = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(2)
    IN_MARKET = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(3)
    MOBILE_APP_INSTALL_USER = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(4)
    VERTICAL_GEO = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(5)
    NEW_SMART_PHONE_USER = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(6)
    def __init__(
        self,
    ) -> None: ...

global___UserInterestTaxonomyTypeEnum = UserInterestTaxonomyTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.recommendation_pb2
import grpc

from .recommendation_service_pb2 import *

class RecommendationServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetRecommendation(
        self,
        request: global___GetRecommendationRequest,
    ) -> google.ads.google_ads.v5.proto.resources.recommendation_pb2.Recommendation: ...
    def ApplyRecommendation(
        self,
        request: global___ApplyRecommendationRequest,
    ) -> global___ApplyRecommendationResponse: ...
    def DismissRecommendation(
        self,
        request: global___DismissRecommendationRequest,
    ) -> global___DismissRecommendationResponse: ...

class RecommendationServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetRecommendation(
        self,
        request: global___GetRecommendationRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.recommendation_pb2.Recommendation: ...
    @abc.abstractmethod
    def ApplyRecommendation(
        self,
        request: global___ApplyRecommendationRequest,
        context: grpc.ServicerContext,
    ) -> global___ApplyRecommendationResponse: ...
    @abc.abstractmethod
    def DismissRecommendation(
        self,
        request: global___DismissRecommendationRequest,
        context: grpc.ServicerContext,
    ) -> global___DismissRecommendationResponse: ...

def add_RecommendationServiceServicer_to_server(
    servicer: RecommendationServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .keyword_plan_idea_service_pb2 import *

class KeywordPlanIdeaServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GenerateKeywordIdeas(
        self,
        request: global___GenerateKeywordIdeasRequest,
    ) -> global___GenerateKeywordIdeaResponse: ...

class KeywordPlanIdeaServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GenerateKeywordIdeas(
        self,
        request: global___GenerateKeywordIdeasRequest,
        context: grpc.ServicerContext,
    ) -> global___GenerateKeywordIdeaResponse: ...

def add_KeywordPlanIdeaServiceServicer_to_server(
    servicer: KeywordPlanIdeaServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GeoTargetConstantSuggestionErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _GeoTargetConstantSuggestionError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            GeoTargetConstantSuggestionError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(0)
        )
        UNKNOWN = (
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(1)
        )
        LOCATION_NAME_SIZE_LIMIT = (
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(2)
        )
        LOCATION_NAME_LIMIT = (
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(3)
        )
        INVALID_COUNTRY_CODE = (
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(4)
        )
        REQUEST_PARAMETERS_UNSET = (
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(5)
        )
    class GeoTargetConstantSuggestionError(metaclass=_GeoTargetConstantSuggestionError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = (
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(0)
    )
    UNKNOWN = GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(1)
    LOCATION_NAME_SIZE_LIMIT = (
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(2)
    )
    LOCATION_NAME_LIMIT = (
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(3)
    )
    INVALID_COUNTRY_CODE = (
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(4)
    )
    REQUEST_PARAMETERS_UNSET = (
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(5)
    )
    def __init__(
        self,
    ) -> None: ...

global___GeoTargetConstantSuggestionErrorEnum = GeoTargetConstantSuggestionErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.dates_pb2
import google.ads.google_ads.v6.proto.enums.invoice_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Invoice(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class AccountBudgetSummary(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CUSTOMER_FIELD_NUMBER: builtins.int
        CUSTOMER_DESCRIPTIVE_NAME_FIELD_NUMBER: builtins.int
        ACCOUNT_BUDGET_FIELD_NUMBER: builtins.int
        ACCOUNT_BUDGET_NAME_FIELD_NUMBER: builtins.int
        PURCHASE_ORDER_NUMBER_FIELD_NUMBER: builtins.int
        SUBTOTAL_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
        TAX_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
        TOTAL_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
        BILLABLE_ACTIVITY_DATE_RANGE_FIELD_NUMBER: builtins.int
        customer: typing.Text = ...
        customer_descriptive_name: typing.Text = ...
        account_budget: typing.Text = ...
        account_budget_name: typing.Text = ...
        purchase_order_number: typing.Text = ...
        subtotal_amount_micros: builtins.int = ...
        tax_amount_micros: builtins.int = ...
        total_amount_micros: builtins.int = ...
        @property
        def billable_activity_date_range(
            self,
        ) -> google.ads.google_ads.v6.proto.common.dates_pb2.DateRange: ...
        def __init__(
            self,
            *,
            customer: typing.Text = ...,
            customer_descriptive_name: typing.Text = ...,
            account_budget: typing.Text = ...,
            account_budget_name: typing.Text = ...,
            purchase_order_number: typing.Text = ...,
            subtotal_amount_micros: builtins.int = ...,
            tax_amount_micros: builtins.int = ...,
            total_amount_micros: builtins.int = ...,
            billable_activity_date_range: typing.Optional[
                google.ads.google_ads.v6.proto.common.dates_pb2.DateRange
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_account_budget",
                b"_account_budget",
                "_account_budget_name",
                b"_account_budget_name",
                "_customer",
                b"_customer",
                "_customer_descriptive_name",
                b"_customer_descriptive_name",
                "_purchase_order_number",
                b"_purchase_order_number",
                "_subtotal_amount_micros",
                b"_subtotal_amount_micros",
                "_tax_amount_micros",
                b"_tax_amount_micros",
                "_total_amount_micros",
                b"_total_amount_micros",
                "account_budget",
                b"account_budget",
                "account_budget_name",
                b"account_budget_name",
                "billable_activity_date_range",
                b"billable_activity_date_range",
                "customer",
                b"customer",
                "customer_descriptive_name",
                b"customer_descriptive_name",
                "purchase_order_number",
                b"purchase_order_number",
                "subtotal_amount_micros",
                b"subtotal_amount_micros",
                "tax_amount_micros",
                b"tax_amount_micros",
                "total_amount_micros",
                b"total_amount_micros",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_account_budget",
                b"_account_budget",
                "_account_budget_name",
                b"_account_budget_name",
                "_customer",
                b"_customer",
                "_customer_descriptive_name",
                b"_customer_descriptive_name",
                "_purchase_order_number",
                b"_purchase_order_number",
                "_subtotal_amount_micros",
                b"_subtotal_amount_micros",
                "_tax_amount_micros",
                b"_tax_amount_micros",
                "_total_amount_micros",
                b"_total_amount_micros",
                "account_budget",
                b"account_budget",
                "account_budget_name",
                b"account_budget_name",
                "billable_activity_date_range",
                b"billable_activity_date_range",
                "customer",
                b"customer",
                "customer_descriptive_name",
                b"customer_descriptive_name",
                "purchase_order_number",
                b"purchase_order_number",
                "subtotal_amount_micros",
                b"subtotal_amount_micros",
                "tax_amount_micros",
                b"tax_amount_micros",
                "total_amount_micros",
                b"total_amount_micros",
            ],
        ) -> None: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_account_budget", b"_account_budget"
            ],
        ) -> typing_extensions.Literal["account_budget"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_account_budget_name", b"_account_budget_name"
            ],
        ) -> typing_extensions.Literal["account_budget_name"]: ...
        @typing.overload
        def WhichOneof(
            self, oneof_group: typing_extensions.Literal["_customer", b"_customer"]
        ) -> typing_extensions.Literal["customer"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_customer_descriptive_name", b"_customer_descriptive_name"
            ],
        ) -> typing_extensions.Literal["customer_descriptive_name"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_purchase_order_number", b"_purchase_order_number"
            ],
        ) -> typing_extensions.Literal["purchase_order_number"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_subtotal_amount_micros", b"_subtotal_amount_micros"
            ],
        ) -> typing_extensions.Literal["subtotal_amount_micros"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_tax_amount_micros", b"_tax_amount_micros"
            ],
        ) -> typing_extensions.Literal["tax_amount_micros"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_total_amount_micros", b"_total_amount_micros"
            ],
        ) -> typing_extensions.Literal["total_amount_micros"]: ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    BILLING_SETUP_FIELD_NUMBER: builtins.int
    PAYMENTS_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    PAYMENTS_PROFILE_ID_FIELD_NUMBER: builtins.int
    ISSUE_DATE_FIELD_NUMBER: builtins.int
    DUE_DATE_FIELD_NUMBER: builtins.int
    SERVICE_DATE_RANGE_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    ADJUSTMENTS_SUBTOTAL_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    ADJUSTMENTS_TAX_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    ADJUSTMENTS_TOTAL_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    REGULATORY_COSTS_SUBTOTAL_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    REGULATORY_COSTS_TAX_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    REGULATORY_COSTS_TOTAL_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    SUBTOTAL_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    TAX_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    TOTAL_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    CORRECTED_INVOICE_FIELD_NUMBER: builtins.int
    REPLACED_INVOICES_FIELD_NUMBER: builtins.int
    PDF_URL_FIELD_NUMBER: builtins.int
    ACCOUNT_BUDGET_SUMMARIES_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: typing.Text = ...
    type: google.ads.google_ads.v6.proto.enums.invoice_type_pb2.InvoiceTypeEnum.InvoiceType.V = (
        ...
    )
    billing_setup: typing.Text = ...
    payments_account_id: typing.Text = ...
    payments_profile_id: typing.Text = ...
    issue_date: typing.Text = ...
    due_date: typing.Text = ...
    currency_code: typing.Text = ...
    adjustments_subtotal_amount_micros: builtins.int = ...
    adjustments_tax_amount_micros: builtins.int = ...
    adjustments_total_amount_micros: builtins.int = ...
    regulatory_costs_subtotal_amount_micros: builtins.int = ...
    regulatory_costs_tax_amount_micros: builtins.int = ...
    regulatory_costs_total_amount_micros: builtins.int = ...
    subtotal_amount_micros: builtins.int = ...
    tax_amount_micros: builtins.int = ...
    total_amount_micros: builtins.int = ...
    corrected_invoice: typing.Text = ...
    replaced_invoices: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    pdf_url: typing.Text = ...
    @property
    def service_date_range(
        self,
    ) -> google.ads.google_ads.v6.proto.common.dates_pb2.DateRange: ...
    @property
    def account_budget_summaries(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___Invoice.AccountBudgetSummary
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Text = ...,
        type: google.ads.google_ads.v6.proto.enums.invoice_type_pb2.InvoiceTypeEnum.InvoiceType.V = ...,
        billing_setup: typing.Text = ...,
        payments_account_id: typing.Text = ...,
        payments_profile_id: typing.Text = ...,
        issue_date: typing.Text = ...,
        due_date: typing.Text = ...,
        service_date_range: typing.Optional[
            google.ads.google_ads.v6.proto.common.dates_pb2.DateRange
        ] = ...,
        currency_code: typing.Text = ...,
        adjustments_subtotal_amount_micros: builtins.int = ...,
        adjustments_tax_amount_micros: builtins.int = ...,
        adjustments_total_amount_micros: builtins.int = ...,
        regulatory_costs_subtotal_amount_micros: builtins.int = ...,
        regulatory_costs_tax_amount_micros: builtins.int = ...,
        regulatory_costs_total_amount_micros: builtins.int = ...,
        subtotal_amount_micros: builtins.int = ...,
        tax_amount_micros: builtins.int = ...,
        total_amount_micros: builtins.int = ...,
        corrected_invoice: typing.Text = ...,
        replaced_invoices: typing.Optional[typing.Iterable[typing.Text]] = ...,
        pdf_url: typing.Text = ...,
        account_budget_summaries: typing.Optional[
            typing.Iterable[global___Invoice.AccountBudgetSummary]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_billing_setup",
            b"_billing_setup",
            "_corrected_invoice",
            b"_corrected_invoice",
            "_currency_code",
            b"_currency_code",
            "_due_date",
            b"_due_date",
            "_id",
            b"_id",
            "_issue_date",
            b"_issue_date",
            "_payments_account_id",
            b"_payments_account_id",
            "_payments_profile_id",
            b"_payments_profile_id",
            "_pdf_url",
            b"_pdf_url",
            "_subtotal_amount_micros",
            b"_subtotal_amount_micros",
            "_tax_amount_micros",
            b"_tax_amount_micros",
            "_total_amount_micros",
            b"_total_amount_micros",
            "billing_setup",
            b"billing_setup",
            "corrected_invoice",
            b"corrected_invoice",
            "currency_code",
            b"currency_code",
            "due_date",
            b"due_date",
            "id",
            b"id",
            "issue_date",
            b"issue_date",
            "payments_account_id",
            b"payments_account_id",
            "payments_profile_id",
            b"payments_profile_id",
            "pdf_url",
            b"pdf_url",
            "service_date_range",
            b"service_date_range",
            "subtotal_amount_micros",
            b"subtotal_amount_micros",
            "tax_amount_micros",
            b"tax_amount_micros",
            "total_amount_micros",
            b"total_amount_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_billing_setup",
            b"_billing_setup",
            "_corrected_invoice",
            b"_corrected_invoice",
            "_currency_code",
            b"_currency_code",
            "_due_date",
            b"_due_date",
            "_id",
            b"_id",
            "_issue_date",
            b"_issue_date",
            "_payments_account_id",
            b"_payments_account_id",
            "_payments_profile_id",
            b"_payments_profile_id",
            "_pdf_url",
            b"_pdf_url",
            "_subtotal_amount_micros",
            b"_subtotal_amount_micros",
            "_tax_amount_micros",
            b"_tax_amount_micros",
            "_total_amount_micros",
            b"_total_amount_micros",
            "account_budget_summaries",
            b"account_budget_summaries",
            "adjustments_subtotal_amount_micros",
            b"adjustments_subtotal_amount_micros",
            "adjustments_tax_amount_micros",
            b"adjustments_tax_amount_micros",
            "adjustments_total_amount_micros",
            b"adjustments_total_amount_micros",
            "billing_setup",
            b"billing_setup",
            "corrected_invoice",
            b"corrected_invoice",
            "currency_code",
            b"currency_code",
            "due_date",
            b"due_date",
            "id",
            b"id",
            "issue_date",
            b"issue_date",
            "payments_account_id",
            b"payments_account_id",
            "payments_profile_id",
            b"payments_profile_id",
            "pdf_url",
            b"pdf_url",
            "regulatory_costs_subtotal_amount_micros",
            b"regulatory_costs_subtotal_amount_micros",
            "regulatory_costs_tax_amount_micros",
            b"regulatory_costs_tax_amount_micros",
            "regulatory_costs_total_amount_micros",
            b"regulatory_costs_total_amount_micros",
            "replaced_invoices",
            b"replaced_invoices",
            "resource_name",
            b"resource_name",
            "service_date_range",
            b"service_date_range",
            "subtotal_amount_micros",
            b"subtotal_amount_micros",
            "tax_amount_micros",
            b"tax_amount_micros",
            "total_amount_micros",
            b"total_amount_micros",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_billing_setup", b"_billing_setup"],
    ) -> typing_extensions.Literal["billing_setup"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_corrected_invoice", b"_corrected_invoice"
        ],
    ) -> typing_extensions.Literal["corrected_invoice"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions.Literal["currency_code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_due_date", b"_due_date"]
    ) -> typing_extensions.Literal["due_date"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_issue_date", b"_issue_date"]
    ) -> typing_extensions.Literal["issue_date"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_payments_account_id", b"_payments_account_id"
        ],
    ) -> typing_extensions.Literal["payments_account_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_payments_profile_id", b"_payments_profile_id"
        ],
    ) -> typing_extensions.Literal["payments_profile_id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_pdf_url", b"_pdf_url"]
    ) -> typing_extensions.Literal["pdf_url"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_subtotal_amount_micros", b"_subtotal_amount_micros"
        ],
    ) -> typing_extensions.Literal["subtotal_amount_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_tax_amount_micros", b"_tax_amount_micros"
        ],
    ) -> typing_extensions.Literal["tax_amount_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_total_amount_micros", b"_total_amount_micros"
        ],
    ) -> typing_extensions.Literal["total_amount_micros"]: ...

global___Invoice = Invoice



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MediaUploadErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MediaUploadError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MediaUploadError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MediaUploadErrorEnum.MediaUploadError.V(0)
        UNKNOWN = MediaUploadErrorEnum.MediaUploadError.V(1)
        FILE_TOO_BIG = MediaUploadErrorEnum.MediaUploadError.V(2)
        UNPARSEABLE_IMAGE = MediaUploadErrorEnum.MediaUploadError.V(3)
        ANIMATED_IMAGE_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(4)
        FORMAT_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(5)
        EXTERNAL_URL_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(6)
        INVALID_URL_REFERENCE = MediaUploadErrorEnum.MediaUploadError.V(7)
        MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = MediaUploadErrorEnum.MediaUploadError.V(8)
        ANIMATED_VISUAL_EFFECT = MediaUploadErrorEnum.MediaUploadError.V(9)
        ANIMATION_TOO_LONG = MediaUploadErrorEnum.MediaUploadError.V(10)
        ASPECT_RATIO_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(11)
        AUDIO_NOT_ALLOWED_IN_MEDIA_BUNDLE = MediaUploadErrorEnum.MediaUploadError.V(12)
        CMYK_JPEG_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(13)
        FLASH_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(14)
        FRAME_RATE_TOO_HIGH = MediaUploadErrorEnum.MediaUploadError.V(15)
        GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED = (
            MediaUploadErrorEnum.MediaUploadError.V(16)
        )
        IMAGE_CONSTRAINTS_VIOLATED = MediaUploadErrorEnum.MediaUploadError.V(17)
        INVALID_MEDIA_BUNDLE = MediaUploadErrorEnum.MediaUploadError.V(18)
        INVALID_MEDIA_BUNDLE_ENTRY = MediaUploadErrorEnum.MediaUploadError.V(19)
        INVALID_MIME_TYPE = MediaUploadErrorEnum.MediaUploadError.V(20)
        INVALID_PATH = MediaUploadErrorEnum.MediaUploadError.V(21)
        LAYOUT_PROBLEM = MediaUploadErrorEnum.MediaUploadError.V(22)
        MALFORMED_URL = MediaUploadErrorEnum.MediaUploadError.V(23)
        MEDIA_BUNDLE_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(24)
        MEDIA_BUNDLE_NOT_COMPATIBLE_TO_PRODUCT_TYPE = (
            MediaUploadErrorEnum.MediaUploadError.V(25)
        )
        MEDIA_BUNDLE_REJECTED_BY_MULTIPLE_ASSET_SPECS = (
            MediaUploadErrorEnum.MediaUploadError.V(26)
        )
        TOO_MANY_FILES_IN_MEDIA_BUNDLE = MediaUploadErrorEnum.MediaUploadError.V(27)
        UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT = (
            MediaUploadErrorEnum.MediaUploadError.V(28)
        )
        UNSUPPORTED_HTML5_FEATURE = MediaUploadErrorEnum.MediaUploadError.V(29)
        URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT = MediaUploadErrorEnum.MediaUploadError.V(
            30
        )
        VIDEO_FILE_NAME_TOO_LONG = MediaUploadErrorEnum.MediaUploadError.V(31)
        VIDEO_MULTIPLE_FILES_WITH_SAME_NAME = MediaUploadErrorEnum.MediaUploadError.V(
            32
        )
        VIDEO_NOT_ALLOWED_IN_MEDIA_BUNDLE = MediaUploadErrorEnum.MediaUploadError.V(33)
        CANNOT_UPLOAD_MEDIA_TYPE_THROUGH_API = MediaUploadErrorEnum.MediaUploadError.V(
            34
        )
    class MediaUploadError(metaclass=_MediaUploadError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MediaUploadErrorEnum.MediaUploadError.V(0)
    UNKNOWN = MediaUploadErrorEnum.MediaUploadError.V(1)
    FILE_TOO_BIG = MediaUploadErrorEnum.MediaUploadError.V(2)
    UNPARSEABLE_IMAGE = MediaUploadErrorEnum.MediaUploadError.V(3)
    ANIMATED_IMAGE_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(4)
    FORMAT_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(5)
    EXTERNAL_URL_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(6)
    INVALID_URL_REFERENCE = MediaUploadErrorEnum.MediaUploadError.V(7)
    MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = MediaUploadErrorEnum.MediaUploadError.V(8)
    ANIMATED_VISUAL_EFFECT = MediaUploadErrorEnum.MediaUploadError.V(9)
    ANIMATION_TOO_LONG = MediaUploadErrorEnum.MediaUploadError.V(10)
    ASPECT_RATIO_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(11)
    AUDIO_NOT_ALLOWED_IN_MEDIA_BUNDLE = MediaUploadErrorEnum.MediaUploadError.V(12)
    CMYK_JPEG_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(13)
    FLASH_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(14)
    FRAME_RATE_TOO_HIGH = MediaUploadErrorEnum.MediaUploadError.V(15)
    GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED = (
        MediaUploadErrorEnum.MediaUploadError.V(16)
    )
    IMAGE_CONSTRAINTS_VIOLATED = MediaUploadErrorEnum.MediaUploadError.V(17)
    INVALID_MEDIA_BUNDLE = MediaUploadErrorEnum.MediaUploadError.V(18)
    INVALID_MEDIA_BUNDLE_ENTRY = MediaUploadErrorEnum.MediaUploadError.V(19)
    INVALID_MIME_TYPE = MediaUploadErrorEnum.MediaUploadError.V(20)
    INVALID_PATH = MediaUploadErrorEnum.MediaUploadError.V(21)
    LAYOUT_PROBLEM = MediaUploadErrorEnum.MediaUploadError.V(22)
    MALFORMED_URL = MediaUploadErrorEnum.MediaUploadError.V(23)
    MEDIA_BUNDLE_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(24)
    MEDIA_BUNDLE_NOT_COMPATIBLE_TO_PRODUCT_TYPE = (
        MediaUploadErrorEnum.MediaUploadError.V(25)
    )
    MEDIA_BUNDLE_REJECTED_BY_MULTIPLE_ASSET_SPECS = (
        MediaUploadErrorEnum.MediaUploadError.V(26)
    )
    TOO_MANY_FILES_IN_MEDIA_BUNDLE = MediaUploadErrorEnum.MediaUploadError.V(27)
    UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT = (
        MediaUploadErrorEnum.MediaUploadError.V(28)
    )
    UNSUPPORTED_HTML5_FEATURE = MediaUploadErrorEnum.MediaUploadError.V(29)
    URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT = MediaUploadErrorEnum.MediaUploadError.V(30)
    VIDEO_FILE_NAME_TOO_LONG = MediaUploadErrorEnum.MediaUploadError.V(31)
    VIDEO_MULTIPLE_FILES_WITH_SAME_NAME = MediaUploadErrorEnum.MediaUploadError.V(32)
    VIDEO_NOT_ALLOWED_IN_MEDIA_BUNDLE = MediaUploadErrorEnum.MediaUploadError.V(33)
    CANNOT_UPLOAD_MEDIA_TYPE_THROUGH_API = MediaUploadErrorEnum.MediaUploadError.V(34)
    def __init__(
        self,
    ) -> None: ...

global___MediaUploadErrorEnum = MediaUploadErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class EducationPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _EducationPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            EducationPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(0)
        UNKNOWN = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(1)
        PROGRAM_ID = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(2)
        LOCATION_ID = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(3)
        PROGRAM_NAME = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(4)
        AREA_OF_STUDY = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(5)
        PROGRAM_DESCRIPTION = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(
            6
        )
        SCHOOL_NAME = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(7)
        ADDRESS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(8)
        THUMBNAIL_IMAGE_URL = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(
            9
        )
        ALTERNATIVE_THUMBNAIL_IMAGE_URL = (
            EducationPlaceholderFieldEnum.EducationPlaceholderField.V(10)
        )
        FINAL_URLS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(11)
        FINAL_MOBILE_URLS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(
            12
        )
        TRACKING_URL = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(13)
        CONTEXTUAL_KEYWORDS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(
            14
        )
        ANDROID_APP_LINK = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(15)
        SIMILAR_PROGRAM_IDS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(
            16
        )
        IOS_APP_LINK = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(17)
        IOS_APP_STORE_ID = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(18)
    class EducationPlaceholderField(metaclass=_EducationPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(0)
    UNKNOWN = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(1)
    PROGRAM_ID = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(2)
    LOCATION_ID = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(3)
    PROGRAM_NAME = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(4)
    AREA_OF_STUDY = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(5)
    PROGRAM_DESCRIPTION = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(6)
    SCHOOL_NAME = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(7)
    ADDRESS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(8)
    THUMBNAIL_IMAGE_URL = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(9)
    ALTERNATIVE_THUMBNAIL_IMAGE_URL = (
        EducationPlaceholderFieldEnum.EducationPlaceholderField.V(10)
    )
    FINAL_URLS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(11)
    FINAL_MOBILE_URLS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(12)
    TRACKING_URL = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(13)
    CONTEXTUAL_KEYWORDS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(14)
    ANDROID_APP_LINK = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(15)
    SIMILAR_PROGRAM_IDS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(16)
    IOS_APP_LINK = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(17)
    IOS_APP_STORE_ID = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(18)
    def __init__(
        self,
    ) -> None: ...

global___EducationPlaceholderFieldEnum = EducationPlaceholderFieldEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum(
    google.protobuf.message.Message
):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PolicyTopicEvidenceDestinationNotWorkingDnsErrorType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V(
            0
        )
        UNKNOWN = PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V(
            1
        )
        HOSTNAME_NOT_FOUND = PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V(
            2
        )
        GOOGLE_CRAWLER_DNS_ISSUE = PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V(
            3
        )
    class PolicyTopicEvidenceDestinationNotWorkingDnsErrorType(
        metaclass=_PolicyTopicEvidenceDestinationNotWorkingDnsErrorType
    ):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V(
        0
    )
    UNKNOWN = PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V(
        1
    )
    HOSTNAME_NOT_FOUND = PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V(
        2
    )
    GOOGLE_CRAWLER_DNS_ISSUE = PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V(
        3
    )
    def __init__(
        self,
    ) -> None: ...

global___PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum = (
    PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum
)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.bidding_pb2
import google.ads.google_ads.v6.proto.enums.bidding_strategy_status_pb2
import google.ads.google_ads.v6.proto.enums.bidding_strategy_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BiddingStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    EFFECTIVE_CURRENCY_CODE_FIELD_NUMBER: builtins.int
    CAMPAIGN_COUNT_FIELD_NUMBER: builtins.int
    NON_REMOVED_CAMPAIGN_COUNT_FIELD_NUMBER: builtins.int
    ENHANCED_CPC_FIELD_NUMBER: builtins.int
    MAXIMIZE_CONVERSION_VALUE_FIELD_NUMBER: builtins.int
    MAXIMIZE_CONVERSIONS_FIELD_NUMBER: builtins.int
    TARGET_CPA_FIELD_NUMBER: builtins.int
    TARGET_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    TARGET_ROAS_FIELD_NUMBER: builtins.int
    TARGET_SPEND_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    name: typing.Text = ...
    status: google.ads.google_ads.v6.proto.enums.bidding_strategy_status_pb2.BiddingStrategyStatusEnum.BiddingStrategyStatus.V = (
        ...
    )
    type: google.ads.google_ads.v6.proto.enums.bidding_strategy_type_pb2.BiddingStrategyTypeEnum.BiddingStrategyType.V = (
        ...
    )
    effective_currency_code: typing.Text = ...
    campaign_count: builtins.int = ...
    non_removed_campaign_count: builtins.int = ...
    @property
    def enhanced_cpc(
        self,
    ) -> google.ads.google_ads.v6.proto.common.bidding_pb2.EnhancedCpc: ...
    @property
    def maximize_conversion_value(
        self,
    ) -> google.ads.google_ads.v6.proto.common.bidding_pb2.MaximizeConversionValue: ...
    @property
    def maximize_conversions(
        self,
    ) -> google.ads.google_ads.v6.proto.common.bidding_pb2.MaximizeConversions: ...
    @property
    def target_cpa(
        self,
    ) -> google.ads.google_ads.v6.proto.common.bidding_pb2.TargetCpa: ...
    @property
    def target_impression_share(
        self,
    ) -> google.ads.google_ads.v6.proto.common.bidding_pb2.TargetImpressionShare: ...
    @property
    def target_roas(
        self,
    ) -> google.ads.google_ads.v6.proto.common.bidding_pb2.TargetRoas: ...
    @property
    def target_spend(
        self,
    ) -> google.ads.google_ads.v6.proto.common.bidding_pb2.TargetSpend: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        name: typing.Text = ...,
        status: google.ads.google_ads.v6.proto.enums.bidding_strategy_status_pb2.BiddingStrategyStatusEnum.BiddingStrategyStatus.V = ...,
        type: google.ads.google_ads.v6.proto.enums.bidding_strategy_type_pb2.BiddingStrategyTypeEnum.BiddingStrategyType.V = ...,
        effective_currency_code: typing.Text = ...,
        campaign_count: builtins.int = ...,
        non_removed_campaign_count: builtins.int = ...,
        enhanced_cpc: typing.Optional[
            google.ads.google_ads.v6.proto.common.bidding_pb2.EnhancedCpc
        ] = ...,
        maximize_conversion_value: typing.Optional[
            google.ads.google_ads.v6.proto.common.bidding_pb2.MaximizeConversionValue
        ] = ...,
        maximize_conversions: typing.Optional[
            google.ads.google_ads.v6.proto.common.bidding_pb2.MaximizeConversions
        ] = ...,
        target_cpa: typing.Optional[
            google.ads.google_ads.v6.proto.common.bidding_pb2.TargetCpa
        ] = ...,
        target_impression_share: typing.Optional[
            google.ads.google_ads.v6.proto.common.bidding_pb2.TargetImpressionShare
        ] = ...,
        target_roas: typing.Optional[
            google.ads.google_ads.v6.proto.common.bidding_pb2.TargetRoas
        ] = ...,
        target_spend: typing.Optional[
            google.ads.google_ads.v6.proto.common.bidding_pb2.TargetSpend
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_campaign_count",
            b"_campaign_count",
            "_effective_currency_code",
            b"_effective_currency_code",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_non_removed_campaign_count",
            b"_non_removed_campaign_count",
            "campaign_count",
            b"campaign_count",
            "effective_currency_code",
            b"effective_currency_code",
            "enhanced_cpc",
            b"enhanced_cpc",
            "id",
            b"id",
            "maximize_conversion_value",
            b"maximize_conversion_value",
            "maximize_conversions",
            b"maximize_conversions",
            "name",
            b"name",
            "non_removed_campaign_count",
            b"non_removed_campaign_count",
            "scheme",
            b"scheme",
            "target_cpa",
            b"target_cpa",
            "target_impression_share",
            b"target_impression_share",
            "target_roas",
            b"target_roas",
            "target_spend",
            b"target_spend",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_campaign_count",
            b"_campaign_count",
            "_effective_currency_code",
            b"_effective_currency_code",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_non_removed_campaign_count",
            b"_non_removed_campaign_count",
            "campaign_count",
            b"campaign_count",
            "effective_currency_code",
            b"effective_currency_code",
            "enhanced_cpc",
            b"enhanced_cpc",
            "id",
            b"id",
            "maximize_conversion_value",
            b"maximize_conversion_value",
            "maximize_conversions",
            b"maximize_conversions",
            "name",
            b"name",
            "non_removed_campaign_count",
            b"non_removed_campaign_count",
            "resource_name",
            b"resource_name",
            "scheme",
            b"scheme",
            "status",
            b"status",
            "target_cpa",
            b"target_cpa",
            "target_impression_share",
            b"target_impression_share",
            "target_roas",
            b"target_roas",
            "target_spend",
            b"target_spend",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_campaign_count", b"_campaign_count"],
    ) -> typing_extensions.Literal["campaign_count"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_effective_currency_code", b"_effective_currency_code"
        ],
    ) -> typing_extensions.Literal["effective_currency_code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_non_removed_campaign_count", b"_non_removed_campaign_count"
        ],
    ) -> typing_extensions.Literal["non_removed_campaign_count"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["scheme", b"scheme"]
    ) -> typing_extensions.Literal[
        "enhanced_cpc",
        "maximize_conversion_value",
        "maximize_conversions",
        "target_cpa",
        "target_impression_share",
        "target_roas",
        "target_spend",
    ]: ...

global___BiddingStrategy = BiddingStrategy



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DateErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _DateError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DateError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = DateErrorEnum.DateError.V(0)
        UNKNOWN = DateErrorEnum.DateError.V(1)
        INVALID_FIELD_VALUES_IN_DATE = DateErrorEnum.DateError.V(2)
        INVALID_FIELD_VALUES_IN_DATE_TIME = DateErrorEnum.DateError.V(3)
        INVALID_STRING_DATE = DateErrorEnum.DateError.V(4)
        INVALID_STRING_DATE_TIME_MICROS = DateErrorEnum.DateError.V(6)
        INVALID_STRING_DATE_TIME_SECONDS = DateErrorEnum.DateError.V(11)
        INVALID_STRING_DATE_TIME_SECONDS_WITH_OFFSET = DateErrorEnum.DateError.V(12)
        EARLIER_THAN_MINIMUM_DATE = DateErrorEnum.DateError.V(7)
        LATER_THAN_MAXIMUM_DATE = DateErrorEnum.DateError.V(8)
        DATE_RANGE_MINIMUM_DATE_LATER_THAN_MAXIMUM_DATE = DateErrorEnum.DateError.V(9)
        DATE_RANGE_MINIMUM_AND_MAXIMUM_DATES_BOTH_NULL = DateErrorEnum.DateError.V(10)
    class DateError(metaclass=_DateError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = DateErrorEnum.DateError.V(0)
    UNKNOWN = DateErrorEnum.DateError.V(1)
    INVALID_FIELD_VALUES_IN_DATE = DateErrorEnum.DateError.V(2)
    INVALID_FIELD_VALUES_IN_DATE_TIME = DateErrorEnum.DateError.V(3)
    INVALID_STRING_DATE = DateErrorEnum.DateError.V(4)
    INVALID_STRING_DATE_TIME_MICROS = DateErrorEnum.DateError.V(6)
    INVALID_STRING_DATE_TIME_SECONDS = DateErrorEnum.DateError.V(11)
    INVALID_STRING_DATE_TIME_SECONDS_WITH_OFFSET = DateErrorEnum.DateError.V(12)
    EARLIER_THAN_MINIMUM_DATE = DateErrorEnum.DateError.V(7)
    LATER_THAN_MAXIMUM_DATE = DateErrorEnum.DateError.V(8)
    DATE_RANGE_MINIMUM_DATE_LATER_THAN_MAXIMUM_DATE = DateErrorEnum.DateError.V(9)
    DATE_RANGE_MINIMUM_AND_MAXIMUM_DATES_BOTH_NULL = DateErrorEnum.DateError.V(10)
    def __init__(
        self,
    ) -> None: ...

global___DateErrorEnum = DateErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.common.keyword_plan_common_pb2
import google.ads.google_ads.v4.proto.enums.keyword_plan_network_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenerateKeywordIdeasRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    GEO_TARGET_CONSTANTS_FIELD_NUMBER: builtins.int
    INCLUDE_ADULT_KEYWORDS_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_NETWORK_FIELD_NUMBER: builtins.int
    KEYWORD_AND_URL_SEED_FIELD_NUMBER: builtins.int
    KEYWORD_SEED_FIELD_NUMBER: builtins.int
    URL_SEED_FIELD_NUMBER: builtins.int
    SITE_SEED_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    include_adult_keywords: builtins.bool = ...
    page_token: typing.Text = ...
    page_size: builtins.int = ...
    keyword_plan_network: google.ads.google_ads.v4.proto.enums.keyword_plan_network_pb2.KeywordPlanNetworkEnum.KeywordPlanNetwork.V = (
        ...
    )
    @property
    def language(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def geo_target_constants(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def keyword_and_url_seed(self) -> global___KeywordAndUrlSeed: ...
    @property
    def keyword_seed(self) -> global___KeywordSeed: ...
    @property
    def url_seed(self) -> global___UrlSeed: ...
    @property
    def site_seed(self) -> global___SiteSeed: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        language: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        geo_target_constants: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        include_adult_keywords: builtins.bool = ...,
        page_token: typing.Text = ...,
        page_size: builtins.int = ...,
        keyword_plan_network: google.ads.google_ads.v4.proto.enums.keyword_plan_network_pb2.KeywordPlanNetworkEnum.KeywordPlanNetwork.V = ...,
        keyword_and_url_seed: typing.Optional[global___KeywordAndUrlSeed] = ...,
        keyword_seed: typing.Optional[global___KeywordSeed] = ...,
        url_seed: typing.Optional[global___UrlSeed] = ...,
        site_seed: typing.Optional[global___SiteSeed] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "keyword_and_url_seed",
            b"keyword_and_url_seed",
            "keyword_seed",
            b"keyword_seed",
            "language",
            b"language",
            "seed",
            b"seed",
            "site_seed",
            b"site_seed",
            "url_seed",
            b"url_seed",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id",
            b"customer_id",
            "geo_target_constants",
            b"geo_target_constants",
            "include_adult_keywords",
            b"include_adult_keywords",
            "keyword_and_url_seed",
            b"keyword_and_url_seed",
            "keyword_plan_network",
            b"keyword_plan_network",
            "keyword_seed",
            b"keyword_seed",
            "language",
            b"language",
            "page_size",
            b"page_size",
            "page_token",
            b"page_token",
            "seed",
            b"seed",
            "site_seed",
            b"site_seed",
            "url_seed",
            b"url_seed",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["seed", b"seed"]
    ) -> typing_extensions.Literal[
        "keyword_and_url_seed", "keyword_seed", "url_seed", "site_seed"
    ]: ...

global___GenerateKeywordIdeasRequest = GenerateKeywordIdeasRequest

class KeywordAndUrlSeed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    URL_FIELD_NUMBER: builtins.int
    KEYWORDS_FIELD_NUMBER: builtins.int
    @property
    def url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def keywords(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    def __init__(
        self,
        *,
        url: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        keywords: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["url", b"url"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["keywords", b"keywords", "url", b"url"],
    ) -> None: ...

global___KeywordAndUrlSeed = KeywordAndUrlSeed

class KeywordSeed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEYWORDS_FIELD_NUMBER: builtins.int
    @property
    def keywords(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    def __init__(
        self,
        *,
        keywords: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["keywords", b"keywords"]
    ) -> None: ...

global___KeywordSeed = KeywordSeed

class SiteSeed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SITE_FIELD_NUMBER: builtins.int
    @property
    def site(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        site: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["site", b"site"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["site", b"site"]
    ) -> None: ...

global___SiteSeed = SiteSeed

class UrlSeed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    URL_FIELD_NUMBER: builtins.int
    @property
    def url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        url: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["url", b"url"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["url", b"url"]
    ) -> None: ...

global___UrlSeed = UrlSeed

class GenerateKeywordIdeaResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    next_page_token: typing.Text = ...
    total_size: builtins.int = ...
    @property
    def results(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___GenerateKeywordIdeaResult
    ]: ...
    def __init__(
        self,
        *,
        results: typing.Optional[
            typing.Iterable[global___GenerateKeywordIdeaResult]
        ] = ...,
        next_page_token: typing.Text = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "next_page_token",
            b"next_page_token",
            "results",
            b"results",
            "total_size",
            b"total_size",
        ],
    ) -> None: ...

global___GenerateKeywordIdeaResponse = GenerateKeywordIdeaResponse

class GenerateKeywordIdeaResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    KEYWORD_IDEA_METRICS_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def keyword_idea_metrics(
        self,
    ) -> google.ads.google_ads.v4.proto.common.keyword_plan_common_pb2.KeywordPlanHistoricalMetrics: ...
    def __init__(
        self,
        *,
        text: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        keyword_idea_metrics: typing.Optional[
            google.ads.google_ads.v4.proto.common.keyword_plan_common_pb2.KeywordPlanHistoricalMetrics
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "keyword_idea_metrics", b"keyword_idea_metrics", "text", b"text"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "keyword_idea_metrics", b"keyword_idea_metrics", "text", b"text"
        ],
    ) -> None: ...

global___GenerateKeywordIdeaResult = GenerateKeywordIdeaResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdTypeEnum.AdType.V(0)
        UNKNOWN = AdTypeEnum.AdType.V(1)
        TEXT_AD = AdTypeEnum.AdType.V(2)
        EXPANDED_TEXT_AD = AdTypeEnum.AdType.V(3)
        CALL_ONLY_AD = AdTypeEnum.AdType.V(6)
        EXPANDED_DYNAMIC_SEARCH_AD = AdTypeEnum.AdType.V(7)
        HOTEL_AD = AdTypeEnum.AdType.V(8)
        SHOPPING_SMART_AD = AdTypeEnum.AdType.V(9)
        SHOPPING_PRODUCT_AD = AdTypeEnum.AdType.V(10)
        VIDEO_AD = AdTypeEnum.AdType.V(12)
        GMAIL_AD = AdTypeEnum.AdType.V(13)
        IMAGE_AD = AdTypeEnum.AdType.V(14)
        RESPONSIVE_SEARCH_AD = AdTypeEnum.AdType.V(15)
        LEGACY_RESPONSIVE_DISPLAY_AD = AdTypeEnum.AdType.V(16)
        APP_AD = AdTypeEnum.AdType.V(17)
        LEGACY_APP_INSTALL_AD = AdTypeEnum.AdType.V(18)
        RESPONSIVE_DISPLAY_AD = AdTypeEnum.AdType.V(19)
        LOCAL_AD = AdTypeEnum.AdType.V(20)
        HTML5_UPLOAD_AD = AdTypeEnum.AdType.V(21)
        DYNAMIC_HTML5_AD = AdTypeEnum.AdType.V(22)
        APP_ENGAGEMENT_AD = AdTypeEnum.AdType.V(23)
        SHOPPING_COMPARISON_LISTING_AD = AdTypeEnum.AdType.V(24)
        VIDEO_BUMPER_AD = AdTypeEnum.AdType.V(25)
        VIDEO_NON_SKIPPABLE_IN_STREAM_AD = AdTypeEnum.AdType.V(26)
        VIDEO_OUTSTREAM_AD = AdTypeEnum.AdType.V(27)
        VIDEO_TRUEVIEW_DISCOVERY_AD = AdTypeEnum.AdType.V(28)
        VIDEO_TRUEVIEW_IN_STREAM_AD = AdTypeEnum.AdType.V(29)
        VIDEO_RESPONSIVE_AD = AdTypeEnum.AdType.V(30)
    class AdType(metaclass=_AdType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdTypeEnum.AdType.V(0)
    UNKNOWN = AdTypeEnum.AdType.V(1)
    TEXT_AD = AdTypeEnum.AdType.V(2)
    EXPANDED_TEXT_AD = AdTypeEnum.AdType.V(3)
    CALL_ONLY_AD = AdTypeEnum.AdType.V(6)
    EXPANDED_DYNAMIC_SEARCH_AD = AdTypeEnum.AdType.V(7)
    HOTEL_AD = AdTypeEnum.AdType.V(8)
    SHOPPING_SMART_AD = AdTypeEnum.AdType.V(9)
    SHOPPING_PRODUCT_AD = AdTypeEnum.AdType.V(10)
    VIDEO_AD = AdTypeEnum.AdType.V(12)
    GMAIL_AD = AdTypeEnum.AdType.V(13)
    IMAGE_AD = AdTypeEnum.AdType.V(14)
    RESPONSIVE_SEARCH_AD = AdTypeEnum.AdType.V(15)
    LEGACY_RESPONSIVE_DISPLAY_AD = AdTypeEnum.AdType.V(16)
    APP_AD = AdTypeEnum.AdType.V(17)
    LEGACY_APP_INSTALL_AD = AdTypeEnum.AdType.V(18)
    RESPONSIVE_DISPLAY_AD = AdTypeEnum.AdType.V(19)
    LOCAL_AD = AdTypeEnum.AdType.V(20)
    HTML5_UPLOAD_AD = AdTypeEnum.AdType.V(21)
    DYNAMIC_HTML5_AD = AdTypeEnum.AdType.V(22)
    APP_ENGAGEMENT_AD = AdTypeEnum.AdType.V(23)
    SHOPPING_COMPARISON_LISTING_AD = AdTypeEnum.AdType.V(24)
    VIDEO_BUMPER_AD = AdTypeEnum.AdType.V(25)
    VIDEO_NON_SKIPPABLE_IN_STREAM_AD = AdTypeEnum.AdType.V(26)
    VIDEO_OUTSTREAM_AD = AdTypeEnum.AdType.V(27)
    VIDEO_TRUEVIEW_DISCOVERY_AD = AdTypeEnum.AdType.V(28)
    VIDEO_TRUEVIEW_IN_STREAM_AD = AdTypeEnum.AdType.V(29)
    VIDEO_RESPONSIVE_AD = AdTypeEnum.AdType.V(30)
    def __init__(
        self,
    ) -> None: ...

global___AdTypeEnum = AdTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ParentalStatusTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ParentalStatusType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ParentalStatusType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ParentalStatusTypeEnum.ParentalStatusType.V(0)
        UNKNOWN = ParentalStatusTypeEnum.ParentalStatusType.V(1)
        PARENT = ParentalStatusTypeEnum.ParentalStatusType.V(300)
        NOT_A_PARENT = ParentalStatusTypeEnum.ParentalStatusType.V(301)
        UNDETERMINED = ParentalStatusTypeEnum.ParentalStatusType.V(302)
    class ParentalStatusType(metaclass=_ParentalStatusType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ParentalStatusTypeEnum.ParentalStatusType.V(0)
    UNKNOWN = ParentalStatusTypeEnum.ParentalStatusType.V(1)
    PARENT = ParentalStatusTypeEnum.ParentalStatusType.V(300)
    NOT_A_PARENT = ParentalStatusTypeEnum.ParentalStatusType.V(301)
    UNDETERMINED = ParentalStatusTypeEnum.ParentalStatusType.V(302)
    def __init__(
        self,
    ) -> None: ...

global___ParentalStatusTypeEnum = ParentalStatusTypeEnum
